# coding: utf-8

"""
    ARLAS CITY API

    Upload GTFS data

    OpenAPI spec version: 0.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import arlas_city_api_python
from arlas_city_api_python.rest import ApiException
from arlas_city_api_python.apis.write_api import WriteApi


class TestWriteApi(unittest.TestCase):
    """ WriteApi unit test stubs """

    def setUp(self):
        self.api = arlas_city_api_python.apis.write_api.WriteApi()

    def tearDown(self):
        pass

    def test_upload(self):
        """
        Test case for upload

        Upload a GTFS archive.
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ARLAS CITY API

    Upload GTFS data

    OpenAPI spec version: 0.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class UploadReport(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job': 'Job',
        'agencies': 'list[str]',
        'statistics': 'FeedStatistics',
        'validation': 'ValidationResults'
    }

    attribute_map = {
        'job': 'job',
        'agencies': 'agencies',
        'statistics': 'statistics',
        'validation': 'validation'
    }

    def __init__(self, job=None, agencies=None, statistics=None, validation=None):
        """
        UploadReport - a model defined in Swagger
        """

        self._job = None
        self._agencies = None
        self._statistics = None
        self._validation = None

        if job is not None:
          self.job = job
        if agencies is not None:
          self.agencies = agencies
        if statistics is not None:
          self.statistics = statistics
        if validation is not None:
          self.validation = validation

    @property
    def job(self):
        """
        Gets the job of this UploadReport.

        :return: The job of this UploadReport.
        :rtype: Job
        """
        return self._job

    @job.setter
    def job(self, job):
        """
        Sets the job of this UploadReport.

        :param job: The job of this UploadReport.
        :type: Job
        """

        self._job = job

    @property
    def agencies(self):
        """
        Gets the agencies of this UploadReport.

        :return: The agencies of this UploadReport.
        :rtype: list[str]
        """
        return self._agencies

    @agencies.setter
    def agencies(self, agencies):
        """
        Sets the agencies of this UploadReport.

        :param agencies: The agencies of this UploadReport.
        :type: list[str]
        """

        self._agencies = agencies

    @property
    def statistics(self):
        """
        Gets the statistics of this UploadReport.

        :return: The statistics of this UploadReport.
        :rtype: FeedStatistics
        """
        return self._statistics

    @statistics.setter
    def statistics(self, statistics):
        """
        Sets the statistics of this UploadReport.

        :param statistics: The statistics of this UploadReport.
        :type: FeedStatistics
        """

        self._statistics = statistics

    @property
    def validation(self):
        """
        Gets the validation of this UploadReport.

        :return: The validation of this UploadReport.
        :rtype: ValidationResults
        """
        return self._validation

    @validation.setter
    def validation(self, validation):
        """
        Sets the validation of this UploadReport.

        :param validation: The validation of this UploadReport.
        :type: ValidationResults
        """

        self._validation = validation

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, UploadReport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    ARLAS CITY API

    Upload GTFS data

    OpenAPI spec version: 0.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class FeedStatistics(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'nb_agencies': 'int',
        'nb_routes': 'int',
        'nb_trips': 'int',
        'nb_stops': 'int',
        'nb_stop_times': 'int',
        'start_date': 'datetime',
        'end_date': 'datetime'
    }

    attribute_map = {
        'nb_agencies': 'nbAgencies',
        'nb_routes': 'nbRoutes',
        'nb_trips': 'nbTrips',
        'nb_stops': 'nbStops',
        'nb_stop_times': 'nbStopTimes',
        'start_date': 'startDate',
        'end_date': 'endDate'
    }

    def __init__(self, nb_agencies=None, nb_routes=None, nb_trips=None, nb_stops=None, nb_stop_times=None, start_date=None, end_date=None):
        """
        FeedStatistics - a model defined in Swagger
        """

        self._nb_agencies = None
        self._nb_routes = None
        self._nb_trips = None
        self._nb_stops = None
        self._nb_stop_times = None
        self._start_date = None
        self._end_date = None

        if nb_agencies is not None:
          self.nb_agencies = nb_agencies
        if nb_routes is not None:
          self.nb_routes = nb_routes
        if nb_trips is not None:
          self.nb_trips = nb_trips
        if nb_stops is not None:
          self.nb_stops = nb_stops
        if nb_stop_times is not None:
          self.nb_stop_times = nb_stop_times
        if start_date is not None:
          self.start_date = start_date
        if end_date is not None:
          self.end_date = end_date

    @property
    def nb_agencies(self):
        """
        Gets the nb_agencies of this FeedStatistics.

        :return: The nb_agencies of this FeedStatistics.
        :rtype: int
        """
        return self._nb_agencies

    @nb_agencies.setter
    def nb_agencies(self, nb_agencies):
        """
        Sets the nb_agencies of this FeedStatistics.

        :param nb_agencies: The nb_agencies of this FeedStatistics.
        :type: int
        """

        self._nb_agencies = nb_agencies

    @property
    def nb_routes(self):
        """
        Gets the nb_routes of this FeedStatistics.

        :return: The nb_routes of this FeedStatistics.
        :rtype: int
        """
        return self._nb_routes

    @nb_routes.setter
    def nb_routes(self, nb_routes):
        """
        Sets the nb_routes of this FeedStatistics.

        :param nb_routes: The nb_routes of this FeedStatistics.
        :type: int
        """

        self._nb_routes = nb_routes

    @property
    def nb_trips(self):
        """
        Gets the nb_trips of this FeedStatistics.

        :return: The nb_trips of this FeedStatistics.
        :rtype: int
        """
        return self._nb_trips

    @nb_trips.setter
    def nb_trips(self, nb_trips):
        """
        Sets the nb_trips of this FeedStatistics.

        :param nb_trips: The nb_trips of this FeedStatistics.
        :type: int
        """

        self._nb_trips = nb_trips

    @property
    def nb_stops(self):
        """
        Gets the nb_stops of this FeedStatistics.

        :return: The nb_stops of this FeedStatistics.
        :rtype: int
        """
        return self._nb_stops

    @nb_stops.setter
    def nb_stops(self, nb_stops):
        """
        Sets the nb_stops of this FeedStatistics.

        :param nb_stops: The nb_stops of this FeedStatistics.
        :type: int
        """

        self._nb_stops = nb_stops

    @property
    def nb_stop_times(self):
        """
        Gets the nb_stop_times of this FeedStatistics.

        :return: The nb_stop_times of this FeedStatistics.
        :rtype: int
        """
        return self._nb_stop_times

    @nb_stop_times.setter
    def nb_stop_times(self, nb_stop_times):
        """
        Sets the nb_stop_times of this FeedStatistics.

        :param nb_stop_times: The nb_stop_times of this FeedStatistics.
        :type: int
        """

        self._nb_stop_times = nb_stop_times

    @property
    def start_date(self):
        """
        Gets the start_date of this FeedStatistics.

        :return: The start_date of this FeedStatistics.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this FeedStatistics.

        :param start_date: The start_date of this FeedStatistics.
        :type: datetime
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this FeedStatistics.

        :return: The end_date of this FeedStatistics.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this FeedStatistics.

        :param end_date: The end_date of this FeedStatistics.
        :type: datetime
        """

        self._end_date = end_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FeedStatistics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    ARLAS CITY API

    Upload GTFS data

    OpenAPI spec version: 0.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class JobResource(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_id': 'str',
        'collection': 'str',
        'operation_id': 'str',
        'created_at': 'int',
        'modified_at': 'int',
        'started_at': 'int',
        'finished_at': 'int',
        'error': 'str',
        'steps': 'list[Step]'
    }

    attribute_map = {
        'job_id': 'job_id',
        'collection': 'collection',
        'operation_id': 'operation_id',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'started_at': 'started_at',
        'finished_at': 'finished_at',
        'error': 'error',
        'steps': 'steps'
    }

    def __init__(self, job_id=None, collection=None, operation_id=None, created_at=None, modified_at=None, started_at=None, finished_at=None, error=None, steps=None):
        """
        JobResource - a model defined in Swagger
        """

        self._job_id = None
        self._collection = None
        self._operation_id = None
        self._created_at = None
        self._modified_at = None
        self._started_at = None
        self._finished_at = None
        self._error = None
        self._steps = None

        if job_id is not None:
          self.job_id = job_id
        if collection is not None:
          self.collection = collection
        if operation_id is not None:
          self.operation_id = operation_id
        if created_at is not None:
          self.created_at = created_at
        if modified_at is not None:
          self.modified_at = modified_at
        if started_at is not None:
          self.started_at = started_at
        if finished_at is not None:
          self.finished_at = finished_at
        if error is not None:
          self.error = error
        if steps is not None:
          self.steps = steps

    @property
    def job_id(self):
        """
        Gets the job_id of this JobResource.

        :return: The job_id of this JobResource.
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """
        Sets the job_id of this JobResource.

        :param job_id: The job_id of this JobResource.
        :type: str
        """

        self._job_id = job_id

    @property
    def collection(self):
        """
        Gets the collection of this JobResource.

        :return: The collection of this JobResource.
        :rtype: str
        """
        return self._collection

    @collection.setter
    def collection(self, collection):
        """
        Sets the collection of this JobResource.

        :param collection: The collection of this JobResource.
        :type: str
        """

        self._collection = collection

    @property
    def operation_id(self):
        """
        Gets the operation_id of this JobResource.

        :return: The operation_id of this JobResource.
        :rtype: str
        """
        return self._operation_id

    @operation_id.setter
    def operation_id(self, operation_id):
        """
        Sets the operation_id of this JobResource.

        :param operation_id: The operation_id of this JobResource.
        :type: str
        """

        self._operation_id = operation_id

    @property
    def created_at(self):
        """
        Gets the created_at of this JobResource.

        :return: The created_at of this JobResource.
        :rtype: int
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this JobResource.

        :param created_at: The created_at of this JobResource.
        :type: int
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """
        Gets the modified_at of this JobResource.

        :return: The modified_at of this JobResource.
        :rtype: int
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """
        Sets the modified_at of this JobResource.

        :param modified_at: The modified_at of this JobResource.
        :type: int
        """

        self._modified_at = modified_at

    @property
    def started_at(self):
        """
        Gets the started_at of this JobResource.

        :return: The started_at of this JobResource.
        :rtype: int
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """
        Sets the started_at of this JobResource.

        :param started_at: The started_at of this JobResource.
        :type: int
        """

        self._started_at = started_at

    @property
    def finished_at(self):
        """
        Gets the finished_at of this JobResource.

        :return: The finished_at of this JobResource.
        :rtype: int
        """
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        """
        Sets the finished_at of this JobResource.

        :param finished_at: The finished_at of this JobResource.
        :type: int
        """

        self._finished_at = finished_at

    @property
    def error(self):
        """
        Gets the error of this JobResource.

        :return: The error of this JobResource.
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """
        Sets the error of this JobResource.

        :param error: The error of this JobResource.
        :type: str
        """

        self._error = error

    @property
    def steps(self):
        """
        Gets the steps of this JobResource.

        :return: The steps of this JobResource.
        :rtype: list[Step]
        """
        return self._steps

    @steps.setter
    def steps(self, steps):
        """
        Sets the steps of this JobResource.

        :param steps: The steps of this JobResource.
        :type: list[Step]
        """

        self._steps = steps

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, JobResource):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    ARLAS CITY API

    Upload GTFS data

    OpenAPI spec version: 0.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ValidationResults(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'routes': 'dict(str, IssuesDetails)',
        'trips': 'dict(str, IssuesDetails)',
        'stops': 'dict(str, IssuesDetails)',
        'shapes': 'dict(str, IssuesDetails)',
        'dates': 'dict(str, IssuesDetails)'
    }

    attribute_map = {
        'routes': 'routes',
        'trips': 'trips',
        'stops': 'stops',
        'shapes': 'shapes',
        'dates': 'dates'
    }

    def __init__(self, routes=None, trips=None, stops=None, shapes=None, dates=None):
        """
        ValidationResults - a model defined in Swagger
        """

        self._routes = None
        self._trips = None
        self._stops = None
        self._shapes = None
        self._dates = None

        if routes is not None:
          self.routes = routes
        if trips is not None:
          self.trips = trips
        if stops is not None:
          self.stops = stops
        if shapes is not None:
          self.shapes = shapes
        if dates is not None:
          self.dates = dates

    @property
    def routes(self):
        """
        Gets the routes of this ValidationResults.

        :return: The routes of this ValidationResults.
        :rtype: dict(str, IssuesDetails)
        """
        return self._routes

    @routes.setter
    def routes(self, routes):
        """
        Sets the routes of this ValidationResults.

        :param routes: The routes of this ValidationResults.
        :type: dict(str, IssuesDetails)
        """

        self._routes = routes

    @property
    def trips(self):
        """
        Gets the trips of this ValidationResults.

        :return: The trips of this ValidationResults.
        :rtype: dict(str, IssuesDetails)
        """
        return self._trips

    @trips.setter
    def trips(self, trips):
        """
        Sets the trips of this ValidationResults.

        :param trips: The trips of this ValidationResults.
        :type: dict(str, IssuesDetails)
        """

        self._trips = trips

    @property
    def stops(self):
        """
        Gets the stops of this ValidationResults.

        :return: The stops of this ValidationResults.
        :rtype: dict(str, IssuesDetails)
        """
        return self._stops

    @stops.setter
    def stops(self, stops):
        """
        Sets the stops of this ValidationResults.

        :param stops: The stops of this ValidationResults.
        :type: dict(str, IssuesDetails)
        """

        self._stops = stops

    @property
    def shapes(self):
        """
        Gets the shapes of this ValidationResults.

        :return: The shapes of this ValidationResults.
        :rtype: dict(str, IssuesDetails)
        """
        return self._shapes

    @shapes.setter
    def shapes(self, shapes):
        """
        Sets the shapes of this ValidationResults.

        :param shapes: The shapes of this ValidationResults.
        :type: dict(str, IssuesDetails)
        """

        self._shapes = shapes

    @property
    def dates(self):
        """
        Gets the dates of this ValidationResults.

        :return: The dates of this ValidationResults.
        :rtype: dict(str, IssuesDetails)
        """
        return self._dates

    @dates.setter
    def dates(self, dates):
        """
        Sets the dates of this ValidationResults.

        :param dates: The dates of this ValidationResults.
        :type: dict(str, IssuesDetails)
        """

        self._dates = dates

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ValidationResults):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    ARLAS CITY API

    Upload GTFS data

    OpenAPI spec version: 0.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Step(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'state': 'str',
        'error': 'str',
        'started_at': 'int',
        'finished_at': 'int'
    }

    attribute_map = {
        'name': 'name',
        'state': 'state',
        'error': 'error',
        'started_at': 'started_at',
        'finished_at': 'finished_at'
    }

    def __init__(self, name=None, state=None, error=None, started_at=None, finished_at=None):
        """
        Step - a model defined in Swagger
        """

        self._name = None
        self._state = None
        self._error = None
        self._started_at = None
        self._finished_at = None

        if name is not None:
          self.name = name
        if state is not None:
          self.state = state
        if error is not None:
          self.error = error
        if started_at is not None:
          self.started_at = started_at
        if finished_at is not None:
          self.finished_at = finished_at

    @property
    def name(self):
        """
        Gets the name of this Step.

        :return: The name of this Step.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Step.

        :param name: The name of this Step.
        :type: str
        """

        self._name = name

    @property
    def state(self):
        """
        Gets the state of this Step.

        :return: The state of this Step.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Step.

        :param state: The state of this Step.
        :type: str
        """

        self._state = state

    @property
    def error(self):
        """
        Gets the error of this Step.

        :return: The error of this Step.
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """
        Sets the error of this Step.

        :param error: The error of this Step.
        :type: str
        """

        self._error = error

    @property
    def started_at(self):
        """
        Gets the started_at of this Step.

        :return: The started_at of this Step.
        :rtype: int
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """
        Sets the started_at of this Step.

        :param started_at: The started_at of this Step.
        :type: int
        """

        self._started_at = started_at

    @property
    def finished_at(self):
        """
        Gets the finished_at of this Step.

        :return: The finished_at of this Step.
        :rtype: int
        """
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        """
        Sets the finished_at of this Step.

        :param finished_at: The finished_at of this Step.
        :type: int
        """

        self._finished_at = finished_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Step):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    ARLAS CITY API

    Upload GTFS data

    OpenAPI spec version: 0.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .error import Error
from .feed_statistics import FeedStatistics
from .issues_details import IssuesDetails
from .job import Job
from .job_resource import JobResource
from .step import Step
from .upload_report import UploadReport
from .validation_results import ValidationResults



# coding: utf-8

"""
    ARLAS City API

    Upload GTFS data

    OpenAPI spec version: 5.0.0
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import sys
from setuptools import setup, find_packages

NAME = "arlas-city_api"
VERSION = "0.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="ARLAS Exploration API",
    author = "Gisaïa",
    author_email="contact@gisaia.com",
    url="https://github.com/gisaia/ARLAS-server",
    keywords=["Arlas", "ARLAS Exploration API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    Explore the content of ARLAS collections
    """
)



# coding: utf-8

"""
    ARLAS CITY API

    Upload GTFS data

    OpenAPI spec version: 0.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.error import Error
from .models.feed_statistics import FeedStatistics
from .models.issues_details import IssuesDetails
from .models.job import Job
from .models.job_resource import JobResource
from .models.step import Step
from .models.upload_report import UploadReport
from .models.validation_results import ValidationResults

# import apis into sdk package
from .apis.status_api import StatusApi
from .apis.write_api import WriteApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()
